@@ -4,6 +4,8 @@ OC.L10N.register(
     "Today" : "Heddiw",
     "Week" : "Wythnos",
     "All" : "Popeth",
+    "Hidden" : "Cudd",
+    "Visible" : "Gweladwy",
     "Automatic" : "Awtomatig",
     "Share with users or groups" : "Rhannwch gyda defnyddwyr neu grwpiau",
     "No users or groups" : "Dim defnyddwyr na grwpiau",
@@ -32,14 +34,15 @@ OC.L10N.register(
     "Could not load deleted calendars and objects" : "Methu llwytho calendrau a gwrthrychau wedi'u dileu",
     "Could not restore calendar or event" : "Methu ag adfer calendr neu ddigwyddiad",
     "Do you really want to empty the trash bin?" : "Ydych chi wir eisiau gwagio'r bin sbwriel?",
+    "Cancel" : "Diddymu",
+    "Close" : "Cau",
     "No errors" : "Dim gwallau",
     "Open your browser console for more details" : "Agorwch eich consol porwr am fwy o fanylion",
     "Last modified" : "Newidiwyd diwethaf",
+    "Alphabetically" : "Trefn yr Wyddor",
     "[Yesterday]" : "[Ddoe]",
     "[Today]" : "Heddiw",
     "[Tomorrow]" : "[Yfory]",
-    "Cancel" : "Diddymu",
-    "Close" : "Cau",
     "All day" : "Drwy'r dydd",
     "Details" : "Manylion",
     "Notes" : "Nodiadau",
