@@ -27,8 +27,12 @@ OC.L10N.register(
     "Deleted" : "Eliminado",
     "Restore" : "Restaurar",
     "Delete permanently" : "Borrar permanentemente",
+    "Empty trash bin" : "Vaciar la papelera",
+    "Cancel" : "Cancelar",
+    "Close" : "Cerrar",
     "No errors" : "Sin errores",
     "Open your browser console for more details" : "Abra la consola de su navegador para más detalles",
+    "Select tags to filter by" : "Seleccione las etiquetas para el filtro",
     "Change sort order" : "Cambiar el criterio para ordenar",
     "Start date" : "Fecha de inicio",
     "Due date" : "Fecha de vencimiento",
@@ -36,8 +40,6 @@ OC.L10N.register(
     "Priority" : "Prioridad",
     "Alphabetically" : "Alfabéticamente",
     "Manually" : "Manualmente",
-    "Cancel" : "Cancelar",
-    "Close" : "Cerrar",
     "_%n Completed Task_::_%n Completed Tasks_" : ["%n Tarea Completada","%n Tareas Completadas","%n Tareas Completadas"],
     "Tomorrow" : "Mañana",
     "All day" : "Todo el día",
