@@ -65,11 +65,16 @@ OC.L10N.register(
     "Delete date" : "Poista päivänmäärä",
     "Set value" : "Aseta arvo",
     "Delete value" : "Poista arvo",
+    "Create new tasks" : "Luo uusia tehtäviä",
+    "Cancel" : "Peruuta",
+    "Create tasks" : "Luo tehtävät",
+    "Close" : "Sulje",
     "Delete all completed tasks." : "Poista kaikki valmistuneet tehtävät.",
     "Delete completed tasks." : "Poista valmistuneet tehtävät.",
     "Deleted all completed tasks from calendar \"{calendar}\"." : "Poista kaikki valmistuneet tehtävät kalenterista \"{calendar}\".",
     "No errors" : "Ei virheitä",
     "Open your browser console for more details" : "Avaa selaimesi konsoli nähdäksesi lisätietoja",
+    "Select tags to filter by" : "Valitse suodatettavat tunnisteet",
     "Add an important task to \"{calendar}\"…" : "Lisää tärkeä tehtävä kalenteriin \"{calendar}\"…",
     "Add a current task to \"{calendar}\"…" : "Lisää nykyinen tehtävä kalenteriin \"{calendar}\"…",
     "Add a task to \"{calendar}\"…" : "Lisää tehtävä kalenteriin \"{calendar}\"…",
@@ -82,9 +87,9 @@ OC.L10N.register(
     "Priority" : "Tärkeys",
     "Alphabetically" : "Aakkosjärjestys",
     "Manually" : "Käsin",
-    "{complete} % completed" : "{complete} % valmiina",
     "Task has hidden subtasks" : "Tehtävällä on piilotettuja alitehtäviä",
     "Task is pinned" : "Tehtävä on kiinnitetty",
+    "{complete} % completed" : "{complete} % valmiina",
     "Add subtask" : "Lisää alitehtävä",
     "Show subtasks" : "Näytä alitehtävät",
     "Hide subtasks" : "Piilota alitehtävät",
@@ -101,23 +106,23 @@ OC.L10N.register(
     "Task is not completed" : "Tehtävää ei ole suoritettu",
     "Create a new task" : "Luo uusi tehtävä",
     "Task summary" : "Tehtävän yhteenveto",
-    "Cancel" : "Peruuta",
     "Create task" : "Luo tehtävä",
     "Creating the new task…" : "Luodaan uutta tehtävää…",
-    "Close" : "Sulje",
     "Open task" : "Avaa tehtävä",
     "\"{task}\" was added to \"{calendar}\"" : "\"{task}\" lisättiin kalenteriin \"{calendar}\"",
     "_%n Completed Task_::_%n Completed Tasks_" : ["%n valmistunut tehtävä","%n valmistunutta tehtävää"],
     "Tomorrow" : "Huomenna",
     "Add List…" : "Lisää lista…",
+    "New list" : "Uusi luettelo",
     "All day" : "Koko päivä",
     "Unpin" : "Poista kiinnitys",
     "Pin" : "Kiinnitä",
     "Show in Calendar" : "Näytä Kalenterissa",
-    "Edit title" : "Muokkaa otsikkoa",
     "Details" : "Tiedot",
     "Select a classification" : "Valitse luokittelu",
     "Select a status" : "Valitse tila",
+    "Set a location" : "Aseta sijainti",
+    "Set a URL" : "Aseta URL-osoite",
     "Select tags" : "Valitse tunnisteet",
     "Notes" : "Muistiinpanot",
     "Reminders" : "Muistutukset",
