@@ -17,7 +17,7 @@ OC.L10N.register(
     "Automatic" : "자동",
     "Share with users or groups" : "사용자 및 그룹과 공유",
     "No users or groups" : "사용자나 그룹 없음",
-    "Can edit" : "편집할 수 있음",
+    "Can edit" : "편집 허용",
     "Unshare with {displayName}" : "{displayName}와(과) 공유 중단",
     "Unable to delete the share." : "이 공유를 삭제할 수 없습니다.",
     "Unable to change permissions." : "권한을 변경할 수 없습니다.",
@@ -54,14 +54,30 @@ OC.L10N.register(
     "Empty trash bin" : "휴지통 비우기",
     "Untitled task" : "제목없는 작업",
     "Untitled event" : "제목없는 일정",
+    "Untitled item" : "제목 없는 항목",
+    "Unknown calendar" : "제목 없는 달력",
     "Could not load deleted calendars and objects" : "삭제된 달력과 요소들을 불러올 수 없음",
     "Could not restore calendar or event" : "달력과 일정을 복구할 수 없음",
     "Do you really want to empty the trash bin?" : "휴지통을 정말 비웁니까?",
+    "Set date" : "날짜 설정",
+    "Set time" : "시간 설정",
+    "Delete date" : "날싸 지우기",
+    "Click here to add a note." : "여기를 눌러 메모를 추가하십시오",
+    "Set value" : "값 지정",
+    "Delete value" : "값 삭제",
+    "Add this as a new tag" : "새 태그로 추가하기",
+    "No tag available. Create one!" : "사용 가능한 태그가 없습니다. 생성하십시오.",
+    "Cancel" : "취소",
+    "Close" : "닫기",
     "Delete all completed tasks." : "모든 완료된 일 지우기",
     "Delete completed tasks." : "완료된 일 지우기",
     "Deleted all completed tasks from calendar \"{calendar}\"." : "\"{calendar}\" 달력의 모든 완료된 일 지우기",
     "No errors" : "오류 없음",
-    "Open your browser console for more details" : "자세한 정보를 보려면 브라우저 콘솔을 여십시오",
+    "Open your browser console for more details" : "자세한 정보를 보려면 브라우저 콘솔을 여세요.",
+    "Active filter" : "활성 필터",
+    "Filter by tags" : "태그로 필터링",
+    "Select tags to filter by" : "필터링할 태그 선택",
+    "Reset filter" : "필터 초기화",
     "Change sort order" : "정렬 순서 변경",
     "Start date" : "시작 날짜",
     "Due date" : "마감 날짜",
@@ -76,13 +92,11 @@ OC.L10N.register(
     "[Today]" : "[오늘]",
     "[Tomorrow]" : "[내일]",
     "Task is completed" : "작업이 완료됨",
-    "Cancel" : "취소",
-    "Close" : "닫기",
+    "Create task" : "작업 만들기",
     "_%n Completed Task_::_%n Completed Tasks_" : ["완료된 작업 %n개"],
     "Tomorrow" : "내일",
     "Add List…" : "리스트 더하기...",
     "All day" : "하루 종일",
-    "Edit title" : "제목 수정",
     "Details" : "세부사항",
     "Select tags" : "태그 선택",
     "Notes" : "Notes",
@@ -95,6 +109,8 @@ OC.L10N.register(
     "Task not found!" : "작업을 찾을 수 없습니다!",
     "Set start date" : "시작 날짜 지점",
     "Set due date" : "만료 기한 설정",
-    "An error occurred" : "오류가 발생함"
+    "Mark as done" : "완료된 것으로 표시",
+    "An error occurred" : "오류가 발생함",
+    "Message from {author} in {conversationName}" : "{conversationName}에서 {author}가 보낸 메시지"
 },
 "nplurals=1; plural=0;");
