@@ -8,10 +8,10 @@ OC.L10N.register(
     "Edit" : "ແກ້ໄຂ",
     "Delete" : "ລຶບ",
     "Unshare" : "ຍົກເລີກການແບ່ງປັນ",
-    "Save" : "ບັນທຶກ",
     "Name" : "ຊື່",
     "Deleted" : "ລືບ",
     "Restore" : "ການກຸ້ຄຶນ",
+    "Empty trash bin" : "ລ້າງຖັງຂີ້ເຫຍື່ອ",
     "Cancel" : "ຍົກເລີກ",
     "Close" : "ປິດ",
     "Details" : "ລາຍລະອຽດ"
