@@ -14,21 +14,37 @@ OC.L10N.register(
     "Automatic" : "Automātisks",
     "Share with users or groups" : "Koplietot ar lietotājiem vai grupām",
     "No users or groups" : "Nav lietotāji vai grupas",
-    "Can edit" : "Var rediģēt",
+    "Can edit" : "Var labot",
+    "Unshare with {displayName}" : "Atcelt kopīgošanu ar {displayName}",
     "Unable to delete the share." : "Nevar izdzēst kopīgošanu.",
     "Unable to change permissions." : "Nevar mainīt atļaujas.",
-    "Edit" : "Rediģēt",
+    "Edit" : "Labot",
     "Copied" : "Nokopēts",
     "Export" : "Eksportēt",
     "Delete" : "Dzēst",
     "Unshare" : "Pārtraukt dalīšanos",
+    "Calendar link copied to clipboard." : "Kalendāra saite nokopēta starpliktuvē.",
+    "Calendar link could not be copied to clipboard." : "Kalendāra saiti nevar nokopēt starpliktuvē.",
     "An empty name is not allowed." : "Nosaukums ir obligāts.",
+    "An error occurred, unable to delete the calendar." : "Radās kļūda, neizdevās izdzēst kalendāru.",
+    "Trash bin" : "Miskaste",
     "Name" : "Vārds",
     "Deleted" : "Dzēstie",
     "Restore" : "Atjaunot",
     "Delete permanently" : "Dzēst pavisam",
+    "Empty trash bin" : "Izdzēst miskastes saturu",
+    "Untitled task" : "Uzdevums bez nosaukuma",
+    "Untitled event" : "Nenosaukts notikums",
+    "Untitled item" : "Nenosaukts vienums",
+    "Unknown calendar" : "Nezināms kalendārs",
+    "Could not load deleted calendars and objects" : "Nevarēja ielādēt dzēstos kalendārus un objektus",
+    "Could not restore calendar or event" : "Nevarēja atjaunot kalendāru vai notikumu.",
+    "Do you really want to empty the trash bin?" : "Vai esat pārliecināts, ka vēlaties neatgriezeniski dzēst miskastes saturu?",
+    "Cancel" : "Atcelt",
+    "Close" : "Aizvērt",
     "No errors" : "Nav kļūdu",
-    "Open your browser console for more details" : "Atveriet savas pārlūkprogrammas konsoli sīkākai informācijai",
+    "Open your browser console for more details" : "Jāatver savas pārlūkprogrammas konsole, lai uzzinātu vairāk",
+    "Select tags to filter by" : "Izvēlieties birkas, pēc kurām filtrēt",
     "Change sort order" : "Mainīt kārtošanas secību",
     "Start date" : "Sākuma datums",
     "Due date" : "Izpildes datums",
@@ -39,8 +55,6 @@ OC.L10N.register(
     "Hide subtasks" : "Slēpt apakšuzdevumus",
     "Hide closed subtasks" : "Slēpt slēgtos apakšuzdevumus",
     "Task is completed" : "Uzdevums pabeigts",
-    "Cancel" : "Atcelt",
-    "Close" : "Aizvērt",
     "_%n Completed Task_::_%n Completed Tasks_" : ["neviena pabeigta uzdevuma","%n paeigts uzdevums","%n pabeigti uzvedumi"],
     "Tomorrow" : "Rīt",
     "All day" : "Visas dienas",
@@ -52,6 +66,7 @@ OC.L10N.register(
     "When shared show full event" : "Ja koplietots, tad rādīt pilnu notikumu",
     "When shared show only busy" : "Ja koplietots, tad rādīt tikai aizņemts",
     "When shared hide this event" : "Ja koplietots, tad paslēpt notikumu",
+    "Canceled" : "Atcelts",
     "Task not found!" : "Uzdevums nav atrasts!",
     "Set start date" : "Uzstādīt sākuma datumu",
     "Set due date" : "Uzstādīt izpildes termiņu",
