@@ -70,6 +70,8 @@ OC.L10N.register(
     "Delete value" : "Cantzella balore",
     "Add this as a new tag" : "Agiunghe custa comente eticheta noa",
     "No tag available. Create one!" : "Peruna eticheta a disponimentu. Crea·dda!",
+    "Cancel" : "Annulla",
+    "Close" : "Serra",
     "Delete all completed tasks." : "Cantzella totu is fainas cumpletadas.",
     "Delete completed tasks." : "Cantzella is fainas cumpletadas.",
     "Deleted all completed tasks from calendar \"{calendar}\"." : "Cantzelladas totu is fainas cumpletadas dae su calendàriu \"{calendar}\".",
@@ -77,6 +79,7 @@ OC.L10N.register(
     "Open your browser console for more details" : "Aberi sa consolla de su navigadore pro àteros detàllios",
     "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["Custu at a cantzellare {taskCount} faina cumpletada e is suta-fainas suas dae su calendàriu \"{calendar}\".","Custu at a cantzellare {taskCount} fainas cumpletadas e is suta-fainas suas dae su calendàriu \"{calendar}\"."],
     "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["No at fatu a cantzellare {failedCount} faina.","No at fatu a cantzellare {failedCount} fainas."],
+    "Select tags to filter by" : "Seletziona etichetas pro filtrare",
     "Add an important task to \"{calendar}\"…" : "Agiunghe una faina importante in \"{calendar}\"…",
     "Add a task due today to \"{calendar}\"…" : "Agiunghe una faina chi agabbat oe a \"{calendar}\"…",
     "Add a current task to \"{calendar}\"…" : "Agiunghe una faina atuale in \"{calendar}\"…",
@@ -95,10 +98,10 @@ OC.L10N.register(
     "Sort by summary and priority." : "Assenta segundu resumu e prioridade.",
     "Manually" : "A manu",
     "Sort by manual order." : "Assenta segundu ordine manuale.",
-    "{complete} % completed" : "{complete} % cumpletadu",
     "Task has hidden subtasks" : "Sa faina tenet suta-fainas cuadas",
     "Task is pinned" : "Sa faina est apicada",
     "Task has a note" : "Sa faina tenet una nota",
+    "{complete} % completed" : "{complete} % cumpletadu",
     "Add subtask" : "Agiunghe suta-faina",
     "Show subtasks" : "Mustra suta-fainas",
     "Hide subtasks" : "Cua suta-fainas",
@@ -125,10 +128,8 @@ OC.L10N.register(
     "Task is completed" : "Sa faina est cumpletada",
     "Create a new task" : "Crea una faina noa",
     "Task summary" : "Resumu de sa faina",
-    "Cancel" : "Annulla",
     "Create task" : "Crea faina",
     "Creating the new task…" : "Creende sa faina noa...",
-    "Close" : "Serra",
     "Open task" : "Aberi faina",
     "\"{task}\" was added to \"{calendar}\"" : "\"{task}\" agiunta a su \"{calendar}\"",
     "_%n Completed Task_::_%n Completed Tasks_" : ["%n Faina cumpletada","%n Fainas cumpletadas"],
@@ -138,7 +139,6 @@ OC.L10N.register(
     "Unpin" : "No apicare",
     "Pin" : "Apica",
     "Show in Calendar" : "Mustra in calendàriu",
-    "Edit title" : "Modìfica tìtulu",
     "Details" : "Detàllios",
     "Select a classification" : "Seletziona una classificatzione",
     "Select a status" : "Seletziona un'istadu",
@@ -168,29 +168,7 @@ OC.L10N.register(
     "Clear status" : "Lìmpia istadu",
     "Loading task from server." : "Carrighende is fainas dae su serbidore.",
     "Task not found!" : "Faina no agatada!",
-    "[Starts today]" : "[Cumintzat oe]",
-    "[Starts tomorrow]" : "[Cumintzat cras]",
-    "[Starts on] LL" : "[Cumintzat su] LL",
-    "[Started yesterday]" : "[Est cumintzadu eris]",
-    "[Started on] LL" : "[Est cumintzadu su] LL",
-    "[Started today at] LT" : "[Est cumintzadu oe a is] LT",
-    "[Starts today at] LT" : "[Cumintzat oe a is] LT",
-    "[Starts tomorrow at] LT" : "[Cumintzat cras a is] LT",
-    "[Starts on] LL [at] LT" : "[Cumintzat su] LL [a is] LT",
-    "[Started yesterday at] LT" : "[Cumintzadu eris a is] LT",
-    "[Started on] LL [at] LT" : "[Cumintzadu su] LL [a is] LT",
     "Set start date" : "Imposta data de cumintzu",
-    "[Due today]" : "[Agabbt oe]",
-    "[Due tomorrow]" : "[Agabbat cras]",
-    "[Due on] LL" : "[Agabbat su] LL",
-    "[Was due yesterday]" : "[Est agabbadu eris]",
-    "[Was due on] LL" : "[Est agabbadu su] LL",
-    "[Was due today at] LT" : "[Est agabbadu oe a is] LT",
-    "[Due today at] LT" : "[Agabbat oe a is] LT",
-    "[Due tomorrow at] LT" : "[Agabbat cras a is] LT",
-    "[Due on] LL [at] LT" : "[Agabbat su] LL [a is] LT",
-    "[Was due yesterday at] LT" : "[Est agabbadu eris a is] LT",
-    "[Was due on] LL [at] LT" : "[Est agabbadu su] LL [a is] LT",
     "Set due date" : "Imposta iscadèntzia",
     "Priority {priority}: low" : "Prioridade {priority}: bàscia",
     "Priority {priority}: medium" : "Prioridade {priority}: mèdia",
@@ -203,8 +181,12 @@ OC.L10N.register(
     "Mark as done" : "Marca comente cumpletadu",
     "No due date assigned" : "Peruna data de iscadèntzia assignada",
     "[Due yesterday]" : "[Agabbadu eris]",
+    "[Due today]" : "[Agabbt oe]",
+    "[Due tomorrow]" : "[Agabbat cras]",
     "[Due] L" : "[Agabbadu] L",
     "[Due yesterday at] LT" : "[Agabbadu eris a] LT",
+    "[Due today at] LT" : "[Agabbat oe a is] LT",
+    "[Due tomorrow at] LT" : "[Agabbat cras a is] LT",
     "[Due] L [at] LT" : "[Agabbadu] L [a] LT",
     "Successfully created the task." : "Faina creada.",
     "Could not delete the task." : "No at fatu a cantzellare sa faina.",
@@ -216,6 +198,24 @@ OC.L10N.register(
     "Task successfully moved to new calendar." : "Faina tramudada a su calendàriu nou.",
     "An error occurred" : "B'at àpidu un'errore",
     "Create a task" : "Crea una faina",
-    "Message from {author} in {conversationName}" : "Messàgiu dae {author} in {conversationName}"
+    "Message from {author} in {conversationName}" : "Messàgiu dae {author} in {conversationName}",
+    "[Due on] LL" : "[Agabbat su] LL",
+    "[Was due yesterday]" : "[Est agabbadu eris]",
+    "[Was due on] LL" : "[Est agabbadu su] LL",
+    "[Was due today at] LT" : "[Est agabbadu oe a is] LT",
+    "[Due on] LL [at] LT" : "[Agabbat su] LL [a is] LT",
+    "[Was due yesterday at] LT" : "[Est agabbadu eris a is] LT",
+    "[Was due on] LL [at] LT" : "[Est agabbadu su] LL [a is] LT",
+    "[Starts today]" : "[Cumintzat oe]",
+    "[Starts tomorrow]" : "[Cumintzat cras]",
+    "[Starts on] LL" : "[Cumintzat su] LL",
+    "[Started yesterday]" : "[Est cumintzadu eris]",
+    "[Started on] LL" : "[Est cumintzadu su] LL",
+    "[Started today at] LT" : "[Est cumintzadu oe a is] LT",
+    "[Starts today at] LT" : "[Cumintzat oe a is] LT",
+    "[Starts tomorrow at] LT" : "[Cumintzat cras a is] LT",
+    "[Starts on] LL [at] LT" : "[Cumintzat su] LL [a is] LT",
+    "[Started yesterday at] LT" : "[Cumintzadu eris a is] LT",
+    "[Started on] LL [at] LT" : "[Cumintzadu su] LL [a is] LT"
 },
 "nplurals=2; plural=(n != 1);");
