@@ -68,6 +68,8 @@ OC.L10N.register(
     "Delete value" : "Ta bort värde",
     "Add this as a new tag" : "Lägg till som en ny tagg",
     "No tag available. Create one!" : "Ingen tagg tillgänglig. Skapa en!",
+    "Cancel" : "Avbryt",
+    "Close" : "Stäng",
     "Delete all completed tasks." : "Ta bort alla slutförda uppgifter.",
     "Delete completed tasks." : "Ta bort slutförda uppgifter.",
     "Deleted all completed tasks from calendar \"{calendar}\"." : "Ta bort alla slutförda uppgifter från kalender \"{calendar}\".",
@@ -75,6 +77,7 @@ OC.L10N.register(
     "Open your browser console for more details" : "Öppna din webbläsarkonsol för mer information",
     "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["Detta kommer att radera {taskCount} slutförd uppgift och dess underuppgifter från kalender \"{calendar}\".","Detta kommer att radera {taskCount} slutförda uppgifter och deras underuppgifter från kalender \"{calendar}\"."],
     "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["Kunde inte radera {failedCount} uppgift.","Kunde inte radera {failedCount} uppgifter."],
+    "Select tags to filter by" : "Välj taggar att filtrera efter",
     "Add an important task to \"{calendar}\"…" : "Lägg till en viktig uppgift till \"{calendar}\"…",
     "Add a task due today to \"{calendar}\"…" : "Lägg till en uppgift som förfaller idag i \"{calendar}\"…",
     "Add a current task to \"{calendar}\"…" : "Lägg till en aktuell uppgift i \"{calendar}\"…",
@@ -106,16 +109,13 @@ OC.L10N.register(
     "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["Raderar uppgiften om {countdown} sekund","Raderar uppgiften om {countdown} sekunder"],
     "Task is completed" : "Uppgift genomförd",
     "Create a new task" : "Skapa ny uppgift",
-    "Cancel" : "Avbryt",
     "Create task" : "Skapa uppgift",
-    "Close" : "Stäng",
     "Open task" : "Öppna uppgift",
     "_%n Completed Task_::_%n Completed Tasks_" : ["%n slutförda uppgifter","%n slutförda uppgifter"],
     "Tomorrow" : "Imorgon",
     "Add List…" : "Lägg till lista...",
     "All day" : "Hela dagen",
     "Show in Calendar" : "Visa i kalender",
-    "Edit title" : "Redigera titel",
     "Details" : "Detaljer",
     "Select a classification" : "Välj en klassificering",
     "Select a status" : "Välj en status",
@@ -132,6 +132,36 @@ OC.L10N.register(
     "Clear status" : "Rensa status",
     "Loading task from server." : "Läser in uppgiften från servern.",
     "Task not found!" : "Uppgift hittades inte!",
+    "Set start date" : "Sätt startdatum",
+    "Set due date" : "Sätt slutdatum",
+    "Priority {priority}: low" : "Prioritet {priority}: låg",
+    "Priority {priority}: medium" : "Prioritet {priority}: medium",
+    "Priority {priority}: high" : "Prioritet {priority}: hög",
+    "No priority assigned" : "Ingen prioritet tilldelad",
+    "{percent} % completed" : "{percent} % slutfört",
+    "Mark as done" : "Markera som klar",
+    "[Due today]" : "[Förfaller idag]",
+    "[Due tomorrow]" : "[Förfaller imorgon]",
+    "[Due today at] LT" : "[Förfaller idag kl] LT",
+    "[Due tomorrow at] LT" : "[Förfaller imorgon kl] LT",
+    "Successfully created the task." : "Uppgiften skapad.",
+    "Could not delete the task." : "Kunde inte radera uppgiften.",
+    "Synchronizing to the server." : "Synkroniserar till servern.",
+    "Task successfully saved to server." : "Uppgiften sparades i servern.",
+    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "Det gick inte att uppdatera uppgiften eftersom den ändrades på servern. Klicka för att uppdatera, lokala ändringar kommer att ignoreras.",
+    "Could not update the task." : "Kunde inte uppdatera uppgiften.",
+    "Successfully updated the task." : "Uppgiften uppdaterad.",
+    "Task successfully moved to new calendar." : "Uppgiften flyttad till en ny kalender.",
+    "An error occurred" : "Ett fel uppstod",
+    "Create a task" : "Skapa en uppgift",
+    "Message from {author} in {conversationName}" : "Meddelande från {author} i {conversationName}",
+    "[Due on] LL" : "[Förfaller på] LL",
+    "[Was due yesterday]" : "[Förföll igår]",
+    "[Was due on] LL" : "[Förföll] LL",
+    "[Was due today at] LT" : "[Förföll idag kl] LT",
+    "[Due on] LL [at] LT" : "[Förfaller på] LL [kl] LT",
+    "[Was due yesterday at] LT" : "[Förföll igår kl] LT",
+    "[Was due on] LL [at] LT" : "[Förföll] LL [kl] LT",
     "[Starts today]" : "[Startar idag]",
     "[Starts tomorrow]" : "[Startar imorgon]",
     "[Starts on] LL" : "[Startar kl] LL",
@@ -142,34 +172,6 @@ OC.L10N.register(
     "[Starts tomorrow at] LT" : "[Startar imorgon kl] LT",
     "[Starts on] LL [at] LT" : "[Startar på] LL [kl] LT",
     "[Started yesterday at] LT" : "[Startade igår kl] LT",
-    "[Started on] LL [at] LT" : "[Startade på] LL [kl] LT",
-    "Set start date" : "Sätt startdatum",
-    "[Due today]" : "[Förfaller idag]",
-    "[Due tomorrow]" : "[Förfaller imorgon]",
-    "[Due on] LL" : "[Förfaller på] LL",
-    "[Was due yesterday]" : "[Förföll igår]",
-    "[Was due on] LL" : "[Förföll] LL",
-    "[Was due today at] LT" : "[Förföll idag kl] LT",
-    "[Due today at] LT" : "[Förfaller idag kl] LT",
-    "[Due tomorrow at] LT" : "[Förfaller imorgon kl] LT",
-    "[Due on] LL [at] LT" : "[Förfaller på] LL [kl] LT",
-    "[Was due yesterday at] LT" : "[Förföll igår kl] LT",
-    "[Was due on] LL [at] LT" : "[Förföll] LL [kl] LT",
-    "Set due date" : "Sätt slutdatum",
-    "Priority {priority}: low" : "Prioritet {priority}: låg",
-    "Priority {priority}: medium" : "Prioritet {priority}: medium",
-    "Priority {priority}: high" : "Prioritet {priority}: hög",
-    "No priority assigned" : "Ingen prioritet tilldelad",
-    "{percent} % completed" : "{percent} % slutfört",
-    "Successfully created the task." : "Uppgiften skapad.",
-    "Could not delete the task." : "Kunde inte radera uppgiften.",
-    "Synchronizing to the server." : "Synkroniserar till servern.",
-    "Task successfully saved to server." : "Uppgiften sparades i servern.",
-    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "Det gick inte att uppdatera uppgiften eftersom den ändrades på servern. Klicka för att uppdatera, lokala ändringar kommer att ignoreras.",
-    "Could not update the task." : "Kunde inte uppdatera uppgiften.",
-    "Successfully updated the task." : "Uppgiften uppdaterad.",
-    "Task successfully moved to new calendar." : "Uppgiften flyttad till en ny kalender.",
-    "An error occurred" : "Ett fel uppstod",
-    "Message from {author} in {conversationName}" : "Meddelande från {author} i {conversationName}"
+    "[Started on] LL [at] LT" : "[Startade på] LL [kl] LT"
 },
 "nplurals=2; plural=(n != 1);");
