@@ -78,6 +78,13 @@ OC.L10N.register(
     "Delete value" : "刪除值",
     "Add this as a new tag" : "將這個新增為新標籤",
     "No tag available. Create one!" : "沒有可用的標籤。建立一個！",
+    "Create new tasks" : "建立新工作項目",
+    "Create {numberOfTasks} tasks from pasted text" : "從貼上的文字建立 {numberOfTasks} 個工作項目",
+    "Cancel" : "取消",
+    "Create tasks" : "建立工作項目",
+    "Creating new tasks…" : "正在建立新的工作項目……",
+    "Close" : "關閉",
+    "{numberOfTasks} tasks have been added to \"{calendar}\"" : "{numberOfTasks} 個工作項目已被新增至「{calendar}」",
     "Delete all completed tasks." : "刪除所有已完成的工作項目。",
     "Delete completed tasks." : "刪除已完成的工作項目。",
     "Deleted all completed tasks from calendar \"{calendar}\"." : "從日曆「{calendar}」刪除了所有已完成的工作項目。",
@@ -85,6 +92,10 @@ OC.L10N.register(
     "Open your browser console for more details" : "開啟您的瀏覽器主控台以取得詳細資訊",
     "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["這將會從日曆「{calendar}」刪除 {taskCount} 個已完成的工作項目與其子項目。"],
     "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["無法刪除 {failedCount} 個工作項目。"],
+    "Active filter" : "作用中的過濾器",
+    "Filter by tags" : "以標籤過濾",
+    "Select tags to filter by" : "依照選擇的標籤篩選",
+    "Reset filter" : "重設篩選條件",
     "Add an important task to \"{calendar}\"…" : "新增重要工作項目到「{calendar}」……",
     "Add a task due today to \"{calendar}\"…" : "新增今天到期的工作項目到「{calendar}」……",
     "Add a current task to \"{calendar}\"…" : "新增目前的工作項目到「{calendar}」……",
@@ -92,6 +103,7 @@ OC.L10N.register(
     "Load the completed tasks of all lists." : "載入所有清單的已完成工作。",
     "Loading the completed tasks of all lists might slow down the app." : "載入所有清單的已完成工作可能會拖慢應用程式的速度。",
     "Load the completed tasks of list \"{calendar}\"." : "載入「{calendar}」清單的已完成工作。",
+    "Loading the completed tasks might slow down the app." : "載入已完成工作可能會拖慢應用程式的速度。",
     "Change sort order" : "改變分類順序",
     "Relevance" : "關聯",
     "Sort by completed state, due date, priority, start date and summary." : "按完成狀態、結束日期、優先程度、開始日期與摘要排序。",
@@ -111,11 +123,10 @@ OC.L10N.register(
     "Sort by summary and priority." : "按摘要與優先程度排序。",
     "Manually" : "手動",
     "Sort by manual order." : "手動排序。",
-    "{complete} % completed" : "{complete} % 完成",
     "Task has hidden subtasks" : "工作項目有隱藏的子工作項目",
-    "Task has not yet started" : "工作項目尚未開始",
     "Task is pinned" : "工作項目已釘選",
     "Task has a note" : "工作項目有註記",
+    "{complete} % completed" : "{complete} % 完成",
     "Add subtask" : "新增子工作項目",
     "Show subtasks" : "顯示子工作項目",
     "Hide subtasks" : "隱藏子工作項目",
@@ -145,25 +156,27 @@ OC.L10N.register(
     "Task is not completed" : "工作項目未完成",
     "Create a new task" : "建立新工作項目",
     "Task summary" : "工作項目摘要",
-    "Cancel" : "取消",
     "Create task" : "建立工作項目",
     "Creating the new task…" : "正在建立新工作項目",
-    "Close" : "關閉",
     "Open task" : "開啟工作項目",
     "\"{task}\" was added to \"{calendar}\"" : "「{task}」已被新增至「{calendar}」",
     "_%n Completed Task_::_%n Completed Tasks_" : ["%n 完成任務"],
     "Tomorrow" : "明天",
     "Add List…" : "增加清單...",
     "New list" : "新清單",
+    "An error occurred, unable to create the list." : "遇到錯誤，無法建立清單。",
     "All day" : "全天",
     "Unpin" : "取消釘選",
     "Pin" : "釘選",
     "Show in Calendar" : "在日曆中顯示",
-    "Edit title" : "編輯標題",
+    "Show in Deck" : "在 Deck 中顯示",
+    "Edit summary" : "編輯摘要",
     "Details" : "詳細資料",
     "Selecting a classification is forbidden, because the task was shared with you." : "因為工作已與您分享，因此您無法選取分類。",
     "Select a classification" : "選取分類",
     "Select a status" : "選取狀態",
+    "Set a location" : "設定位置",
+    "Set a URL" : "設定 URL",
     "Select tags" : "選取標籤",
     "Notes" : "註解",
     "Reminders" : "提醒",
@@ -190,29 +203,7 @@ OC.L10N.register(
     "Clear status" : "清除狀態",
     "Loading task from server." : "正在從伺服器載入工作項目。",
     "Task not found!" : "找不到任務!",
-    "[Starts today]" : "[今天開始]",
-    "[Starts tomorrow]" : "[昨天開始]",
-    "[Starts on] LL" : "[開始於] LL",
-    "[Started yesterday]" : "[昨天開始]",
-    "[Started on] LL" : "[開始於] LL",
-    "[Started today at] LT" : "[今天開始於] LT",
-    "[Starts today at] LT" : "[今天開始於] LT",
-    "[Starts tomorrow at] LT" : "[明天開始於] LT",
-    "[Starts on] LL [at] LT" : "[開始在] LL [於] LT",
-    "[Started yesterday at] LT" : "[昨天開始於] LT",
-    "[Started on] LL [at] LT" : "[開始在] LL [於] LT",
     "Set start date" : "指定開始日期",
-    "[Due today]" : "[今天到期]",
-    "[Due tomorrow]" : "[明天到期]",
-    "[Due on] LL" : "[到期於] LL",
-    "[Was due yesterday]" : "[昨天到期]",
-    "[Was due on] LL" : "[到期於] LL",
-    "[Was due today at] LT" : "[今天到期於] LT",
-    "[Due today at] LT" : "[今天到期於] LT",
-    "[Due tomorrow at] LT" : "[明天到期於] LT",
-    "[Due on] LL [at] LT" : "[到期在] LL [於] LT",
-    "[Was due yesterday at] LT" : "[昨天到期於] LT",
-    "[Was due on] LL [at] LT" : "[到期在] LL [於] LT",
     "Set due date" : "指定到期日",
     "Priority {priority}: low" : "優先程度 {priority}：低",
     "Priority {priority}: medium" : "優先程度 {priority}：中",
@@ -225,8 +216,12 @@ OC.L10N.register(
     "Mark as done" : "標記為完成",
     "No due date assigned" : "未指定到期日",
     "[Due yesterday]" : "[昨天截止]",
+    "[Due today]" : "[今天到期]",
+    "[Due tomorrow]" : "[明天到期]",
     "[Due] L" : "[截止於] L",
     "[Due yesterday at] LT" : "[昨天截止於] LT",
+    "[Due today at] LT" : "[今天到期於] LT",
+    "[Due tomorrow at] LT" : "[明天到期於] LT",
     "[Due] L [at] LT" : "[截止] L [於] LT",
     "Successfully created the task." : "成功建立工作項目。",
     "Could not delete the task." : "無法刪除工作項目。",
@@ -238,6 +233,24 @@ OC.L10N.register(
     "Task successfully moved to new calendar." : "工作項目成功移動到新的日曆。",
     "An error occurred" : "發生錯誤",
     "Create a task" : "建立工作項目",
-    "Message from {author} in {conversationName}" : "來自 {conversationName} 中 {author} 的訊息"
+    "Message from {author} in {conversationName}" : "來自 {conversationName} 中 {author} 的訊息",
+    "[Due on] LL" : "[到期於] LL",
+    "[Was due yesterday]" : "[昨天到期]",
+    "[Was due on] LL" : "[到期於] LL",
+    "[Was due today at] LT" : "[今天到期於] LT",
+    "[Due on] LL [at] LT" : "[到期在] LL [於] LT",
+    "[Was due yesterday at] LT" : "[昨天到期於] LT",
+    "[Was due on] LL [at] LT" : "[到期在] LL [於] LT",
+    "[Starts today]" : "[今天開始]",
+    "[Starts tomorrow]" : "[昨天開始]",
+    "[Starts on] LL" : "[開始於] LL",
+    "[Started yesterday]" : "[昨天開始]",
+    "[Started on] LL" : "[開始於] LL",
+    "[Started today at] LT" : "[今天開始於] LT",
+    "[Starts today at] LT" : "[今天開始於] LT",
+    "[Starts tomorrow at] LT" : "[明天開始於] LT",
+    "[Starts on] LL [at] LT" : "[開始在] LL [於] LT",
+    "[Started yesterday at] LT" : "[昨天開始於] LT",
+    "[Started on] LL [at] LT" : "[開始在] LL [於] LT"
 },
 "nplurals=1; plural=0;");
